Fleet Metrics Vessels
---------------------

.. note::
    available on platforms : Platform.Liquids, Platform.LPG, Platform.LNG

.. autoclass:: kpler.sdk.resources.fleet_metrics_vessels.FleetMetricsVessels
    :members:

.. autoclass:: kpler.sdk.FleetMetricsVesselsAlgo
    :members:

.. autoclass:: kpler.sdk.FleetMetricsVesselsMeasurementUnit
    :members:
    
.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex: